
'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/example/feature.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x16org.tensorflow.exampleB\rFeatureProtosP\x01ZSgithub.com/tensorflow/tensorflow/tensorflow/go/core/example/example_protos_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n%tensorflow/core/example/feature.proto\x12\ntensorflow"\x1a\n\tBytesList\x12\r\n\x05value\x18\x01 \x03(\x0c"\x1e\n\tFloatList\x12\x11\n\x05value\x18\x01 \x03(\x02B\x02\x10\x01"\x1e\n\tInt64List\x12\x11\n\x05value\x18\x01 \x03(\x03B\x02\x10\x01"\x98\x01\n\x07Feature\x12+\n\nbytes_list\x18\x01 \x01(\x0b2\x15.tensorflow.BytesListH\x00\x12+\n\nfloat_list\x18\x02 \x01(\x0b2\x15.tensorflow.FloatListH\x00\x12+\n\nint64_list\x18\x03 \x01(\x0b2\x15.tensorflow.Int64ListH\x00B\x06\n\x04kind"\x83\x01\n\x08Features\x122\n\x07feature\x18\x01 \x03(\x0b2!.tensorflow.Features.FeatureEntry\x1aC\n\x0cFeatureEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12"\n\x05value\x18\x02 \x01(\x0b2\x13.tensorflow.Feature:\x028\x01"3\n\x0bFeatureList\x12$\n\x07feature\x18\x01 \x03(\x0b2\x13.tensorflow.Feature"\x9c\x01\n\x0cFeatureLists\x12?\n\x0cfeature_list\x18\x01 \x03(\x0b2).tensorflow.FeatureLists.FeatureListEntry\x1aK\n\x10FeatureListEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12&\n\x05value\x18\x02 \x01(\x0b2\x17.tensorflow.FeatureList:\x028\x01B\x81\x01\n\x16org.tensorflow.exampleB\rFeatureProtosP\x01ZSgithub.com/tensorflow/tensorflow/tensorflow/go/core/example/example_protos_go_proto\xf8\x01\x01b\x06proto3')
_BYTESLIST = _descriptor.Descriptor(name='BytesList', full_name='tensorflow.BytesList', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='tensorflow.BytesList.value', index=0, number=1, type=12, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=53, serialized_end=79)
_FLOATLIST = _descriptor.Descriptor(name='FloatList', full_name='tensorflow.FloatList', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='tensorflow.FloatList.value', index=0, number=1, type=2, cpp_type=6, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=81, serialized_end=111)
_INT64LIST = _descriptor.Descriptor(name='Int64List', full_name='tensorflow.Int64List', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='value', full_name='tensorflow.Int64List.value', index=0, number=1, type=3, cpp_type=2, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=b'\x10\x01', file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=113, serialized_end=143)
_FEATURE = _descriptor.Descriptor(name='Feature', full_name='tensorflow.Feature', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='bytes_list', full_name='tensorflow.Feature.bytes_list', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='float_list', full_name='tensorflow.Feature.float_list', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='int64_list', full_name='tensorflow.Feature.int64_list', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[_descriptor.OneofDescriptor(name='kind', full_name='tensorflow.Feature.kind', index=0, containing_type=None, create_key=_descriptor._internal_create_key, fields=[])], serialized_start=146, serialized_end=298)
_FEATURES_FEATUREENTRY = _descriptor.Descriptor(name='FeatureEntry', full_name='tensorflow.Features.FeatureEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.Features.FeatureEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.Features.FeatureEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=365, serialized_end=432)
_FEATURES = _descriptor.Descriptor(name='Features', full_name='tensorflow.Features', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature', full_name='tensorflow.Features.feature', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_FEATURES_FEATUREENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=301, serialized_end=432)
_FEATURELIST = _descriptor.Descriptor(name='FeatureList', full_name='tensorflow.FeatureList', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature', full_name='tensorflow.FeatureList.feature', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=434, serialized_end=485)
_FEATURELISTS_FEATURELISTENTRY = _descriptor.Descriptor(name='FeatureListEntry', full_name='tensorflow.FeatureLists.FeatureListEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.FeatureLists.FeatureListEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.FeatureLists.FeatureListEntry.value', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=569, serialized_end=644)
_FEATURELISTS = _descriptor.Descriptor(name='FeatureLists', full_name='tensorflow.FeatureLists', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='feature_list', full_name='tensorflow.FeatureLists.feature_list', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_FEATURELISTS_FEATURELISTENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=488, serialized_end=644)
_FEATURE.fields_by_name['bytes_list'].message_type = _BYTESLIST
_FEATURE.fields_by_name['float_list'].message_type = _FLOATLIST
_FEATURE.fields_by_name['int64_list'].message_type = _INT64LIST
_FEATURE.oneofs_by_name['kind'].fields.append(_FEATURE.fields_by_name['bytes_list'])
_FEATURE.fields_by_name['bytes_list'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(_FEATURE.fields_by_name['float_list'])
_FEATURE.fields_by_name['float_list'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURE.oneofs_by_name['kind'].fields.append(_FEATURE.fields_by_name['int64_list'])
_FEATURE.fields_by_name['int64_list'].containing_oneof = _FEATURE.oneofs_by_name['kind']
_FEATURES_FEATUREENTRY.fields_by_name['value'].message_type = _FEATURE
_FEATURES_FEATUREENTRY.containing_type = _FEATURES
_FEATURES.fields_by_name['feature'].message_type = _FEATURES_FEATUREENTRY
_FEATURELIST.fields_by_name['feature'].message_type = _FEATURE
_FEATURELISTS_FEATURELISTENTRY.fields_by_name['value'].message_type = _FEATURELIST
_FEATURELISTS_FEATURELISTENTRY.containing_type = _FEATURELISTS
_FEATURELISTS.fields_by_name['feature_list'].message_type = _FEATURELISTS_FEATURELISTENTRY
DESCRIPTOR.message_types_by_name['BytesList'] = _BYTESLIST
DESCRIPTOR.message_types_by_name['FloatList'] = _FLOATLIST
DESCRIPTOR.message_types_by_name['Int64List'] = _INT64LIST
DESCRIPTOR.message_types_by_name['Feature'] = _FEATURE
DESCRIPTOR.message_types_by_name['Features'] = _FEATURES
DESCRIPTOR.message_types_by_name['FeatureList'] = _FEATURELIST
DESCRIPTOR.message_types_by_name['FeatureLists'] = _FEATURELISTS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
BytesList = _reflection.GeneratedProtocolMessageType('BytesList', (_message.Message,), {'DESCRIPTOR': _BYTESLIST, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(BytesList)
FloatList = _reflection.GeneratedProtocolMessageType('FloatList', (_message.Message,), {'DESCRIPTOR': _FLOATLIST, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(FloatList)
Int64List = _reflection.GeneratedProtocolMessageType('Int64List', (_message.Message,), {'DESCRIPTOR': _INT64LIST, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(Int64List)
Feature = _reflection.GeneratedProtocolMessageType('Feature', (_message.Message,), {'DESCRIPTOR': _FEATURE, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(Feature)
Features = _reflection.GeneratedProtocolMessageType('Features', (_message.Message,), {'FeatureEntry': _reflection.GeneratedProtocolMessageType('FeatureEntry', (_message.Message,), {'DESCRIPTOR': _FEATURES_FEATUREENTRY, '__module__': 'tensorflow.core.example.feature_pb2'}), 'DESCRIPTOR': _FEATURES, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(Features)
_sym_db.RegisterMessage(Features.FeatureEntry)
FeatureList = _reflection.GeneratedProtocolMessageType('FeatureList', (_message.Message,), {'DESCRIPTOR': _FEATURELIST, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(FeatureList)
FeatureLists = _reflection.GeneratedProtocolMessageType('FeatureLists', (_message.Message,), {'FeatureListEntry': _reflection.GeneratedProtocolMessageType('FeatureListEntry', (_message.Message,), {'DESCRIPTOR': _FEATURELISTS_FEATURELISTENTRY, '__module__': 'tensorflow.core.example.feature_pb2'}), 'DESCRIPTOR': _FEATURELISTS, '__module__': 'tensorflow.core.example.feature_pb2'})
_sym_db.RegisterMessage(FeatureLists)
_sym_db.RegisterMessage(FeatureLists.FeatureListEntry)
DESCRIPTOR._options = None
_FLOATLIST.fields_by_name['value']._options = None
_INT64LIST.fields_by_name['value']._options = None
_FEATURES_FEATUREENTRY._options = None
_FEATURELISTS_FEATURELISTENTRY._options = None



import enum
import dataclasses

class Cache:
  def __init__(self):
    raise NotImplementedError

# // DB contents are stored in a set of blocks, each of which holds a
# // sequence of key,value pairs.  Each block may be compressed before
# // being stored in a file.  The following enum describes which
# // compression method (if any) is used to compress a block.
# enum CompressionType {
#   // NOTE: do not change the values of existing entries, as these are
#   // part of the persistent format on disk.
#   kNoCompression = 0x0,
#   kSnappyCompression = 0x1
# };
class CompressionType(enum.IntEnum):
  kNoCompression = 0x0
  kSnappyCompression = 0x1
kNoCompression = CompressionType.kNoCompression
kSnappyCompression = CompressionType.kSnappyCompression

# // Options to control the behavior of a table (passed to Table::Open)
# struct Options {
#   // Approximate size of user data packed per block.  Note that the
#   // block size specified here corresponds to uncompressed data.  The
#   // actual size of the unit read from disk may be smaller if
#   // compression is enabled.  This parameter can be changed dynamically.
#   size_t block_size = 262144;
#
#   // Number of keys between restart points for delta encoding of keys.
#   // This parameter can be changed dynamically.  Most clients should
#   // leave this parameter alone.
#   int block_restart_interval = 16;
#
#   // Compress blocks using the specified compression algorithm.  This
#   // parameter can be changed dynamically.
#   //
#   // Default: kSnappyCompression, which gives lightweight but fast
#   // compression.
#   //
#   // Typical speeds of kSnappyCompression on an Intel(R) Core(TM)2 2.4GHz:
#   //    ~200-500MB/s compression
#   //    ~400-800MB/s decompression
#   // Note that these speeds are significantly faster than most
#   // persistent storage speeds, and therefore it is typically never
#   // worth switching to kNoCompression.  Even if the input data is
#   // incompressible, the kSnappyCompression implementation will
#   // efficiently detect that and will switch to uncompressed mode.
#   CompressionType compression = kSnappyCompression;
#
#   // Control over blocks (user data is stored in a set of blocks, and
#   // a block is the unit of reading from disk).
#
#   // If non-null, use the specified cache for blocks.
#   Cache* block_cache = nullptr;
# };

@dataclasses.dataclass
class Options:
  # Approximate size of user data packed per block.  Note that the
  # block size specified here corresponds to uncompressed data.  The
  # actual size of the unit read from disk may be smaller if
  # compression is enabled.  This parameter can be changed dynamically.
  block_size: int = 262144

  # Number of keys between restart points for delta encoding of keys.
  # This parameter can be changed dynamically.  Most clients should
  # leave this parameter alone.
  block_restart_interval: int = 16

  # Compress blocks using the specified compression algorithm.  This
  # parameter can be changed dynamically.
  #
  # Default: kSnappyCompression, which gives lightweight but fast
  # compression.
  #
  # Typical speeds of kSnappyCompression on an Intel(R) Core(TM)2 2.4GHz:
  #    ~200-500MB/s compression
  #    ~400-800MB/s decompression
  # Note that these speeds are significantly faster than most
  # persistent storage speeds, and therefore it is typically never
  # worth switching to kNoCompression.  Even if the input data is
  # incompressible, the kSnappyCompression implementation will
  # efficiently detect that and will switch to uncompressed mode.
  compression: CompressionType = kSnappyCompression

  # Control over blocks (user data is stored in a set of blocks, and
  # a block is the unit of reading from disk).
  #
  # If non-null, use the specified cache for blocks.
  block_cache: Cache = None




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import attr_value_pb2 as tensorflow_dot_core_dot_framework_dot_attr__value__pb2
from ....tensorflow.core.framework import full_type_pb2 as tensorflow_dot_core_dot_framework_dot_full__type__pb2
from ....tensorflow.core.framework import resource_handle_pb2 as tensorflow_dot_core_dot_framework_dot_resource__handle__pb2
from ....tensorflow.core.framework import types_pb2 as tensorflow_dot_core_dot_framework_dot_types__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/framework/op_def.proto', package='tensorflow', syntax='proto3', serialized_options=b'\n\x18org.tensorflow.frameworkB\x0bOpDefProtosP\x01ZMgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/op_def_go_proto\xf8\x01\x01', create_key=_descriptor._internal_create_key, serialized_pb=b'\n&tensorflow/core/framework/op_def.proto\x12\ntensorflow\x1a*tensorflow/core/framework/attr_value.proto\x1a)tensorflow/core/framework/full_type.proto\x1a/tensorflow/core/framework/resource_handle.proto\x1a%tensorflow/core/framework/types.proto"\xf3\x06\n\x05OpDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12+\n\tinput_arg\x18\x02 \x03(\x0b2\x18.tensorflow.OpDef.ArgDef\x12,\n\noutput_arg\x18\x03 \x03(\x0b2\x18.tensorflow.OpDef.ArgDef\x12\x16\n\x0econtrol_output\x18\x14 \x03(\t\x12\'\n\x04attr\x18\x04 \x03(\x0b2\x19.tensorflow.OpDef.AttrDef\x12.\n\x0bdeprecation\x18\x08 \x01(\x0b2\x19.tensorflow.OpDeprecation\x12\x0f\n\x07summary\x18\x05 \x01(\t\x12\x13\n\x0bdescription\x18\x06 \x01(\t\x12\x16\n\x0eis_commutative\x18\x12 \x01(\x08\x12\x14\n\x0cis_aggregate\x18\x10 \x01(\x08\x12\x13\n\x0bis_stateful\x18\x11 \x01(\x08\x12"\n\x1aallows_uninitialized_input\x18\x13 \x01(\x08\x12$\n\x1cis_distributed_communication\x18\x15 \x01(\x08\x1a\x9c\x02\n\x06ArgDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0bdescription\x18\x02 \x01(\t\x12"\n\x04type\x18\x03 \x01(\x0e2\x14.tensorflow.DataType\x12\x11\n\ttype_attr\x18\x04 \x01(\t\x12\x13\n\x0bnumber_attr\x18\x05 \x01(\t\x12\x16\n\x0etype_list_attr\x18\x06 \x01(\t\x12B\n\x0bhandle_data\x18\x07 \x03(\x0b2-.tensorflow.ResourceHandleProto.DtypeAndShape\x12\x0e\n\x06is_ref\x18\x10 \x01(\x08\x127\n\x16experimental_full_type\x18\x11 \x01(\x0b2\x17.tensorflow.FullTypeDef\x1a\xbd\x01\n\x07AttrDef\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12,\n\rdefault_value\x18\x03 \x01(\x0b2\x15.tensorflow.AttrValue\x12\x13\n\x0bdescription\x18\x04 \x01(\t\x12\x13\n\x0bhas_minimum\x18\x05 \x01(\x08\x12\x0f\n\x07minimum\x18\x06 \x01(\x03\x12-\n\x0eallowed_values\x18\x07 \x01(\x0b2\x15.tensorflow.AttrValue"5\n\rOpDeprecation\x12\x0f\n\x07version\x18\x01 \x01(\x05\x12\x13\n\x0bexplanation\x18\x02 \x01(\t"\'\n\x06OpList\x12\x1d\n\x02op\x18\x01 \x03(\x0b2\x11.tensorflow.OpDefB{\n\x18org.tensorflow.frameworkB\x0bOpDefProtosP\x01ZMgithub.com/tensorflow/tensorflow/tensorflow/go/core/framework/op_def_go_proto\xf8\x01\x01b\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_attr__value__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_full__type__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_resource__handle__pb2.DESCRIPTOR, tensorflow_dot_core_dot_framework_dot_types__pb2.DESCRIPTOR])
_OPDEF_ARGDEF = _descriptor.Descriptor(name='ArgDef', full_name='tensorflow.OpDef.ArgDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.OpDef.ArgDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.OpDef.ArgDef.description', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.OpDef.ArgDef.type', index=2, number=3, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type_attr', full_name='tensorflow.OpDef.ArgDef.type_attr', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='number_attr', full_name='tensorflow.OpDef.ArgDef.number_attr', index=4, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type_list_attr', full_name='tensorflow.OpDef.ArgDef.type_list_attr', index=5, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='handle_data', full_name='tensorflow.OpDef.ArgDef.handle_data', index=6, number=7, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_ref', full_name='tensorflow.OpDef.ArgDef.is_ref', index=7, number=16, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='experimental_full_type', full_name='tensorflow.OpDef.ArgDef.experimental_full_type', index=8, number=17, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=637, serialized_end=921)
_OPDEF_ATTRDEF = _descriptor.Descriptor(name='AttrDef', full_name='tensorflow.OpDef.AttrDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.OpDef.AttrDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='type', full_name='tensorflow.OpDef.AttrDef.type', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='default_value', full_name='tensorflow.OpDef.AttrDef.default_value', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.OpDef.AttrDef.description', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='has_minimum', full_name='tensorflow.OpDef.AttrDef.has_minimum', index=4, number=5, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='minimum', full_name='tensorflow.OpDef.AttrDef.minimum', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allowed_values', full_name='tensorflow.OpDef.AttrDef.allowed_values', index=6, number=7, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=924, serialized_end=1113)
_OPDEF = _descriptor.Descriptor(name='OpDef', full_name='tensorflow.OpDef', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='name', full_name='tensorflow.OpDef.name', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='input_arg', full_name='tensorflow.OpDef.input_arg', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_arg', full_name='tensorflow.OpDef.output_arg', index=2, number=3, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='control_output', full_name='tensorflow.OpDef.control_output', index=3, number=20, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='attr', full_name='tensorflow.OpDef.attr', index=4, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='deprecation', full_name='tensorflow.OpDef.deprecation', index=5, number=8, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='summary', full_name='tensorflow.OpDef.summary', index=6, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='description', full_name='tensorflow.OpDef.description', index=7, number=6, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_commutative', full_name='tensorflow.OpDef.is_commutative', index=8, number=18, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_aggregate', full_name='tensorflow.OpDef.is_aggregate', index=9, number=16, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_stateful', full_name='tensorflow.OpDef.is_stateful', index=10, number=17, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='allows_uninitialized_input', full_name='tensorflow.OpDef.allows_uninitialized_input', index=11, number=19, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='is_distributed_communication', full_name='tensorflow.OpDef.is_distributed_communication', index=12, number=21, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_OPDEF_ARGDEF, _OPDEF_ATTRDEF], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=230, serialized_end=1113)
_OPDEPRECATION = _descriptor.Descriptor(name='OpDeprecation', full_name='tensorflow.OpDeprecation', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='version', full_name='tensorflow.OpDeprecation.version', index=0, number=1, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='explanation', full_name='tensorflow.OpDeprecation.explanation', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1115, serialized_end=1168)
_OPLIST = _descriptor.Descriptor(name='OpList', full_name='tensorflow.OpList', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='op', full_name='tensorflow.OpList.op', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=1170, serialized_end=1209)
_OPDEF_ARGDEF.fields_by_name['type'].enum_type = tensorflow_dot_core_dot_framework_dot_types__pb2._DATATYPE
_OPDEF_ARGDEF.fields_by_name['handle_data'].message_type = tensorflow_dot_core_dot_framework_dot_resource__handle__pb2._RESOURCEHANDLEPROTO_DTYPEANDSHAPE
_OPDEF_ARGDEF.fields_by_name['experimental_full_type'].message_type = tensorflow_dot_core_dot_framework_dot_full__type__pb2._FULLTYPEDEF
_OPDEF_ARGDEF.containing_type = _OPDEF
_OPDEF_ATTRDEF.fields_by_name['default_value'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._ATTRVALUE
_OPDEF_ATTRDEF.fields_by_name['allowed_values'].message_type = tensorflow_dot_core_dot_framework_dot_attr__value__pb2._ATTRVALUE
_OPDEF_ATTRDEF.containing_type = _OPDEF
_OPDEF.fields_by_name['input_arg'].message_type = _OPDEF_ARGDEF
_OPDEF.fields_by_name['output_arg'].message_type = _OPDEF_ARGDEF
_OPDEF.fields_by_name['attr'].message_type = _OPDEF_ATTRDEF
_OPDEF.fields_by_name['deprecation'].message_type = _OPDEPRECATION
_OPLIST.fields_by_name['op'].message_type = _OPDEF
DESCRIPTOR.message_types_by_name['OpDef'] = _OPDEF
DESCRIPTOR.message_types_by_name['OpDeprecation'] = _OPDEPRECATION
DESCRIPTOR.message_types_by_name['OpList'] = _OPLIST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
OpDef = _reflection.GeneratedProtocolMessageType('OpDef', (_message.Message,), {'ArgDef': _reflection.GeneratedProtocolMessageType('ArgDef', (_message.Message,), {'DESCRIPTOR': _OPDEF_ARGDEF, '__module__': 'tensorflow.core.framework.op_def_pb2'}), 'AttrDef': _reflection.GeneratedProtocolMessageType('AttrDef', (_message.Message,), {'DESCRIPTOR': _OPDEF_ATTRDEF, '__module__': 'tensorflow.core.framework.op_def_pb2'}), 'DESCRIPTOR': _OPDEF, '__module__': 'tensorflow.core.framework.op_def_pb2'})
_sym_db.RegisterMessage(OpDef)
_sym_db.RegisterMessage(OpDef.ArgDef)
_sym_db.RegisterMessage(OpDef.AttrDef)
OpDeprecation = _reflection.GeneratedProtocolMessageType('OpDeprecation', (_message.Message,), {'DESCRIPTOR': _OPDEPRECATION, '__module__': 'tensorflow.core.framework.op_def_pb2'})
_sym_db.RegisterMessage(OpDeprecation)
OpList = _reflection.GeneratedProtocolMessageType('OpList', (_message.Message,), {'DESCRIPTOR': _OPLIST, '__module__': 'tensorflow.core.framework.op_def_pb2'})
_sym_db.RegisterMessage(OpList)
DESCRIPTOR._options = None



# /* Copyright 2016 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================*/
#
# #ifndef TENSORFLOW_CORE_LIB_IO_INPUTSTREAM_INTERFACE_H_
# #define TENSORFLOW_CORE_LIB_IO_INPUTSTREAM_INTERFACE_H_
#
# #include <string>
#
# #include "tensorflow/core/lib/core/errors.h"
# #include "tensorflow/core/lib/core/status.h"
# #include "tensorflow/core/platform/cord.h"
# #include "tensorflow/core/platform/types.h"
#
# namespace tensorflow {
# namespace io {
#
# // An interface that defines input streaming operations.
# class InputStreamInterface {
#  public:
#   InputStreamInterface() {}
#   virtual ~InputStreamInterface() {}
#
#   // Reads the next bytes_to_read from the file. Typical return codes:
#   //  * OK - in case of success.
#   //  * OUT_OF_RANGE - not enough bytes remaining before end of file.
#   virtual Status ReadNBytes(int64 bytes_to_read, tstring* result) = 0;
#
# #if defined(TF_CORD_SUPPORT)
#   // Reads the next bytes_to_read from the file. Typical return codes:
#   //  * OK - in case of success.
#   //  * OUT_OF_RANGE - not enough bytes remaining before end of file.
#   virtual Status ReadNBytes(int64 bytes_to_read, absl::Cord* cord) {
#     return errors::Unimplemented(
#         "ReadNBytes(int64, absl::Cord*) is not implemented.");
#   }
# #endif
#
#   // Skips bytes_to_skip before next ReadNBytes. bytes_to_skip should be >= 0.
#   // Typical return codes:
#   //  * OK - in case of success.
#   //  * OUT_OF_RANGE - not enough bytes remaining before end of file.
#   virtual Status SkipNBytes(int64 bytes_to_skip);
#
#   // Return the offset of the current byte relative to the beginning of the
#   // file.
#   // If we Skip / Read beyond the end of the file, this should return the length
#   // of the file.
#   // If there are any errors, this must return -1.
#   virtual int64 Tell() const = 0;
#
#   // Resets the stream to the beginning.
#   virtual Status Reset() = 0;
# };
#
# }  // namespace io
# }  // namespace tensorflow
#
# #endif  // TENSORFLOW_CORE_LIB_IO_INPUTSTREAM_INTERFACE_H_

# /* Copyright 2016 The TensorFlow Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# ==============================================================================*/
#
# #include "tensorflow/core/lib/io/inputstream_interface.h"
#
# #include "tensorflow/core/lib/core/errors.h"
#
# namespace tensorflow {
# namespace io {
#
# // To limit memory usage, the default implementation of SkipNBytes() only reads
# // 8MB at a time.
# static constexpr int64 kMaxSkipSize = 8 * 1024 * 1024;
#
# Status InputStreamInterface::SkipNBytes(int64 bytes_to_skip) {
#   if (bytes_to_skip < 0) {
#     return errors::InvalidArgument("Can't skip a negative number of bytes");
#   }
#   tstring unused;
#   // Read kDefaultSkipSize at a time till bytes_to_skip.
#   while (bytes_to_skip > 0) {
#     int64 bytes_to_read = std::min<int64>(kMaxSkipSize, bytes_to_skip);
#     TF_RETURN_IF_ERROR(ReadNBytes(bytes_to_read, &unused));
#     bytes_to_skip -= bytes_to_read;
#   }
#   return Status::OK();
# }
#
# }  // namespace io
# }  // namespace tensorflow

from ..... import core
from ..... import errors

from abc import ABC, abstractmethod

from typing import Tuple, Optional

class InputStreamInterface(ABC):
  # // Reads the next bytes_to_read from the file. Typical return codes:
  # //  * OK - in case of success.
  # //  * OUT_OF_RANGE - not enough bytes remaining before end of file.
  # virtual Status ReadNBytes(int64 bytes_to_read, tstring* result) = 0;
  @abstractmethod
  def read_n_bytes(self, bytes_to_read: int) -> Tuple[errors.Status, Optional[bytearray]]:
    """Reads the next bytes_to_read from the file.

    Typical return codes:
     * OK - in case of success.
     * OUT_OF_RANGE - not enough bytes remaining before end of file.
    """
    ...

  # // Skips bytes_to_skip before next ReadNBytes. bytes_to_skip should be >= 0.
  # // Typical return codes:
  # //  * OK - in case of success.
  # //  * OUT_OF_RANGE - not enough bytes remaining before end of file.
  # virtual Status SkipNBytes(int64 bytes_to_skip);
  @abstractmethod
  def skip_n_bytes(self, bytes_to_skip: int) -> errors.Status:
    """Skips bytes_to_skip before next ReadNBytes. bytes_to_skip should be >= 0.

    Typical return codes:
     * OK - in case of success.
     * OUT_OF_RANGE - not enough bytes remaining before end of file.
    """
    ...

  # // Return the offset of the current byte relative to the beginning of the
  # // file.
  # // If we Skip / Read beyond the end of the file, this should return the length
  # // of the file.
  # // If there are any errors, this must return -1.
  # virtual int64 Tell() const = 0;
  @abstractmethod
  def tell(self) -> int:
    """Return the offset of the current byte relative to the beginning of the
    file.

    If we Skip / Read beyond the end of the file, this should return the length
    of the file.

    If there are any errors, this must return -1.
    """
    ...

  # // Resets the stream to the beginning.
  # virtual Status Reset() = 0;
  @abstractmethod
  def reset(self):
    """Resets the stream to the beginning."""
    ...





'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/protobuf/service_config.proto', package='tensorflow.data.experimental', syntax='proto3', serialized_options=b'ZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_proto', create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/core/protobuf/service_config.proto\x12\x1ctensorflow.data.experimental"\x9e\x01\n\x10DispatcherConfig\x12\x0c\n\x04port\x18\x01 \x01(\x03\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x10\n\x08work_dir\x18\x03 \x01(\t\x12\x1b\n\x13fault_tolerant_mode\x18\x04 \x01(\x08\x12 \n\x18job_gc_check_interval_ms\x18\x05 \x01(\x03\x12\x19\n\x11job_gc_timeout_ms\x18\x06 \x01(\x03"\x81\x02\n\x0cWorkerConfig\x12\x0c\n\x04port\x18\x01 \x01(\x03\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x1a\n\x12dispatcher_address\x18\x03 \x01(\t\x12\x16\n\x0eworker_address\x18\x04 \x01(\t\x12\x1d\n\x15heartbeat_interval_ms\x18\x05 \x01(\x03\x12\x1d\n\x15dispatcher_timeout_ms\x18\x06 \x01(\x03\x12\x1e\n\x16data_transfer_protocol\x18\x07 \x01(\t\x12\x1d\n\x15data_transfer_address\x18\x08 \x01(\t\x12 \n\x18shutdown_quiet_period_ms\x18\t \x01(\x03BWZUgithub.com/tensorflow/tensorflow/tensorflow/go/core/protobuf/for_core_protos_go_protob\x06proto3')
_DISPATCHERCONFIG = _descriptor.Descriptor(name='DispatcherConfig', full_name='tensorflow.data.experimental.DispatcherConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='port', full_name='tensorflow.data.experimental.DispatcherConfig.port', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='protocol', full_name='tensorflow.data.experimental.DispatcherConfig.protocol', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='work_dir', full_name='tensorflow.data.experimental.DispatcherConfig.work_dir', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='fault_tolerant_mode', full_name='tensorflow.data.experimental.DispatcherConfig.fault_tolerant_mode', index=3, number=4, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_gc_check_interval_ms', full_name='tensorflow.data.experimental.DispatcherConfig.job_gc_check_interval_ms', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='job_gc_timeout_ms', full_name='tensorflow.data.experimental.DispatcherConfig.job_gc_timeout_ms', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=80, serialized_end=238)
_WORKERCONFIG = _descriptor.Descriptor(name='WorkerConfig', full_name='tensorflow.data.experimental.WorkerConfig', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='port', full_name='tensorflow.data.experimental.WorkerConfig.port', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='protocol', full_name='tensorflow.data.experimental.WorkerConfig.protocol', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dispatcher_address', full_name='tensorflow.data.experimental.WorkerConfig.dispatcher_address', index=2, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='worker_address', full_name='tensorflow.data.experimental.WorkerConfig.worker_address', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='heartbeat_interval_ms', full_name='tensorflow.data.experimental.WorkerConfig.heartbeat_interval_ms', index=4, number=5, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='dispatcher_timeout_ms', full_name='tensorflow.data.experimental.WorkerConfig.dispatcher_timeout_ms', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_transfer_protocol', full_name='tensorflow.data.experimental.WorkerConfig.data_transfer_protocol', index=6, number=7, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='data_transfer_address', full_name='tensorflow.data.experimental.WorkerConfig.data_transfer_address', index=7, number=8, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='shutdown_quiet_period_ms', full_name='tensorflow.data.experimental.WorkerConfig.shutdown_quiet_period_ms', index=8, number=9, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=241, serialized_end=498)
DESCRIPTOR.message_types_by_name['DispatcherConfig'] = _DISPATCHERCONFIG
DESCRIPTOR.message_types_by_name['WorkerConfig'] = _WORKERCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
DispatcherConfig = _reflection.GeneratedProtocolMessageType('DispatcherConfig', (_message.Message,), {'DESCRIPTOR': _DISPATCHERCONFIG, '__module__': 'tensorflow.core.protobuf.service_config_pb2'})
_sym_db.RegisterMessage(DispatcherConfig)
WorkerConfig = _reflection.GeneratedProtocolMessageType('WorkerConfig', (_message.Message,), {'DESCRIPTOR': _WORKERCONFIG, '__module__': 'tensorflow.core.protobuf.service_config_pb2'})
_sym_db.RegisterMessage(WorkerConfig)
DESCRIPTOR._options = None



from . import bundle_reader
from . import env
from . import core

class NewCheckpointReader:
  def __init__(self, filename):
    self._reader = bundle_reader.BundleReader(env.Env.default(), filename)

  def get_variable_to_shape_map(self):
    return {name.decode('utf-8'): arr.shape for name, arr in self._reader._tensors}

  def get_variable_to_dtype_map(self):
    return {name.decode('utf-8'): arr.dtype for name, arr in self._reader._tensors}

  def get_tensor(self, name):
    name = core.string_view(name).bytes()
    for k, v in self._reader._tensors:
      if k == name:
        return v





'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.profiler import profiler_service_pb2 as tensorflow_dot_core_dot_profiler_dot_profiler__service__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/profiler/profiler_analysis.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n0tensorflow/core/profiler/profiler_analysis.proto\x12\ntensorflow\x1a/tensorflow/core/profiler/profiler_service.proto"\x83\x01\n\x18NewProfileSessionRequest\x12+\n\x07request\x18\x01 \x01(\x0b2\x1a.tensorflow.ProfileRequest\x12\x17\n\x0frepository_root\x18\x02 \x01(\t\x12\r\n\x05hosts\x18\x03 \x03(\t\x12\x12\n\nsession_id\x18\x04 \x01(\t"G\n\x19NewProfileSessionResponse\x12\x15\n\rerror_message\x18\x01 \x01(\t\x12\x13\n\x0bempty_trace\x18\x02 \x01(\x08"=\n"EnumProfileSessionsAndToolsRequest\x12\x17\n\x0frepository_root\x18\x01 \x01(\t"A\n\x12ProfileSessionInfo\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x17\n\x0favailable_tools\x18\x02 \x03(\t"n\n#EnumProfileSessionsAndToolsResponse\x12\x15\n\rerror_message\x18\x01 \x01(\t\x120\n\x08sessions\x18\x02 \x03(\x0b2\x1e.tensorflow.ProfileSessionInfo"\xec\x01\n\x19ProfileSessionDataRequest\x12\x17\n\x0frepository_root\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x11\n\thost_name\x18\x05 \x01(\t\x12\x11\n\ttool_name\x18\x03 \x01(\t\x12I\n\nparameters\x18\x04 \x03(\x0b25.tensorflow.ProfileSessionDataRequest.ParametersEntry\x1a1\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"Z\n\x1aProfileSessionDataResponse\x12\x15\n\rerror_message\x18\x01 \x01(\t\x12\x15\n\routput_format\x18\x02 \x01(\t\x12\x0e\n\x06output\x18\x03 \x01(\x0c2\xc8\x02\n\x0fProfileAnalysis\x12[\n\nNewSession\x12$.tensorflow.NewProfileSessionRequest\x1a%.tensorflow.NewProfileSessionResponse"\x00\x12q\n\x0cEnumSessions\x12..tensorflow.EnumProfileSessionsAndToolsRequest\x1a/.tensorflow.EnumProfileSessionsAndToolsResponse"\x00\x12e\n\x12GetSessionToolData\x12%.tensorflow.ProfileSessionDataRequest\x1a&.tensorflow.ProfileSessionDataResponse"\x00b\x06proto3', dependencies=[tensorflow_dot_core_dot_profiler_dot_profiler__service__pb2.DESCRIPTOR])
_NEWPROFILESESSIONREQUEST = _descriptor.Descriptor(name='NewProfileSessionRequest', full_name='tensorflow.NewProfileSessionRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='request', full_name='tensorflow.NewProfileSessionRequest.request', index=0, number=1, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='repository_root', full_name='tensorflow.NewProfileSessionRequest.repository_root', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='hosts', full_name='tensorflow.NewProfileSessionRequest.hosts', index=2, number=3, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_id', full_name='tensorflow.NewProfileSessionRequest.session_id', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=114, serialized_end=245)
_NEWPROFILESESSIONRESPONSE = _descriptor.Descriptor(name='NewProfileSessionResponse', full_name='tensorflow.NewProfileSessionResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='error_message', full_name='tensorflow.NewProfileSessionResponse.error_message', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='empty_trace', full_name='tensorflow.NewProfileSessionResponse.empty_trace', index=1, number=2, type=8, cpp_type=7, label=1, has_default_value=False, default_value=False, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=247, serialized_end=318)
_ENUMPROFILESESSIONSANDTOOLSREQUEST = _descriptor.Descriptor(name='EnumProfileSessionsAndToolsRequest', full_name='tensorflow.EnumProfileSessionsAndToolsRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='repository_root', full_name='tensorflow.EnumProfileSessionsAndToolsRequest.repository_root', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=320, serialized_end=381)
_PROFILESESSIONINFO = _descriptor.Descriptor(name='ProfileSessionInfo', full_name='tensorflow.ProfileSessionInfo', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='session_id', full_name='tensorflow.ProfileSessionInfo.session_id', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='available_tools', full_name='tensorflow.ProfileSessionInfo.available_tools', index=1, number=2, type=9, cpp_type=9, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=383, serialized_end=448)
_ENUMPROFILESESSIONSANDTOOLSRESPONSE = _descriptor.Descriptor(name='EnumProfileSessionsAndToolsResponse', full_name='tensorflow.EnumProfileSessionsAndToolsResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='error_message', full_name='tensorflow.EnumProfileSessionsAndToolsResponse.error_message', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='sessions', full_name='tensorflow.EnumProfileSessionsAndToolsResponse.sessions', index=1, number=2, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=450, serialized_end=560)
_PROFILESESSIONDATAREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(name='ParametersEntry', full_name='tensorflow.ProfileSessionDataRequest.ParametersEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.ProfileSessionDataRequest.ParametersEntry.key', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.ProfileSessionDataRequest.ParametersEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=750, serialized_end=799)
_PROFILESESSIONDATAREQUEST = _descriptor.Descriptor(name='ProfileSessionDataRequest', full_name='tensorflow.ProfileSessionDataRequest', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='repository_root', full_name='tensorflow.ProfileSessionDataRequest.repository_root', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='session_id', full_name='tensorflow.ProfileSessionDataRequest.session_id', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='host_name', full_name='tensorflow.ProfileSessionDataRequest.host_name', index=2, number=5, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tool_name', full_name='tensorflow.ProfileSessionDataRequest.tool_name', index=3, number=3, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='parameters', full_name='tensorflow.ProfileSessionDataRequest.parameters', index=4, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_PROFILESESSIONDATAREQUEST_PARAMETERSENTRY], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=563, serialized_end=799)
_PROFILESESSIONDATARESPONSE = _descriptor.Descriptor(name='ProfileSessionDataResponse', full_name='tensorflow.ProfileSessionDataResponse', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='error_message', full_name='tensorflow.ProfileSessionDataResponse.error_message', index=0, number=1, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_format', full_name='tensorflow.ProfileSessionDataResponse.output_format', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output', full_name='tensorflow.ProfileSessionDataResponse.output', index=2, number=3, type=12, cpp_type=9, label=1, has_default_value=False, default_value=b'', message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=801, serialized_end=891)
_NEWPROFILESESSIONREQUEST.fields_by_name['request'].message_type = tensorflow_dot_core_dot_profiler_dot_profiler__service__pb2._PROFILEREQUEST
_ENUMPROFILESESSIONSANDTOOLSRESPONSE.fields_by_name['sessions'].message_type = _PROFILESESSIONINFO
_PROFILESESSIONDATAREQUEST_PARAMETERSENTRY.containing_type = _PROFILESESSIONDATAREQUEST
_PROFILESESSIONDATAREQUEST.fields_by_name['parameters'].message_type = _PROFILESESSIONDATAREQUEST_PARAMETERSENTRY
DESCRIPTOR.message_types_by_name['NewProfileSessionRequest'] = _NEWPROFILESESSIONREQUEST
DESCRIPTOR.message_types_by_name['NewProfileSessionResponse'] = _NEWPROFILESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['EnumProfileSessionsAndToolsRequest'] = _ENUMPROFILESESSIONSANDTOOLSREQUEST
DESCRIPTOR.message_types_by_name['ProfileSessionInfo'] = _PROFILESESSIONINFO
DESCRIPTOR.message_types_by_name['EnumProfileSessionsAndToolsResponse'] = _ENUMPROFILESESSIONSANDTOOLSRESPONSE
DESCRIPTOR.message_types_by_name['ProfileSessionDataRequest'] = _PROFILESESSIONDATAREQUEST
DESCRIPTOR.message_types_by_name['ProfileSessionDataResponse'] = _PROFILESESSIONDATARESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
NewProfileSessionRequest = _reflection.GeneratedProtocolMessageType('NewProfileSessionRequest', (_message.Message,), {'DESCRIPTOR': _NEWPROFILESESSIONREQUEST, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(NewProfileSessionRequest)
NewProfileSessionResponse = _reflection.GeneratedProtocolMessageType('NewProfileSessionResponse', (_message.Message,), {'DESCRIPTOR': _NEWPROFILESESSIONRESPONSE, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(NewProfileSessionResponse)
EnumProfileSessionsAndToolsRequest = _reflection.GeneratedProtocolMessageType('EnumProfileSessionsAndToolsRequest', (_message.Message,), {'DESCRIPTOR': _ENUMPROFILESESSIONSANDTOOLSREQUEST, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(EnumProfileSessionsAndToolsRequest)
ProfileSessionInfo = _reflection.GeneratedProtocolMessageType('ProfileSessionInfo', (_message.Message,), {'DESCRIPTOR': _PROFILESESSIONINFO, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(ProfileSessionInfo)
EnumProfileSessionsAndToolsResponse = _reflection.GeneratedProtocolMessageType('EnumProfileSessionsAndToolsResponse', (_message.Message,), {'DESCRIPTOR': _ENUMPROFILESESSIONSANDTOOLSRESPONSE, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(EnumProfileSessionsAndToolsResponse)
ProfileSessionDataRequest = _reflection.GeneratedProtocolMessageType('ProfileSessionDataRequest', (_message.Message,), {'ParametersEntry': _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {'DESCRIPTOR': _PROFILESESSIONDATAREQUEST_PARAMETERSENTRY, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'}), 'DESCRIPTOR': _PROFILESESSIONDATAREQUEST, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(ProfileSessionDataRequest)
_sym_db.RegisterMessage(ProfileSessionDataRequest.ParametersEntry)
ProfileSessionDataResponse = _reflection.GeneratedProtocolMessageType('ProfileSessionDataResponse', (_message.Message,), {'DESCRIPTOR': _PROFILESESSIONDATARESPONSE, '__module__': 'tensorflow.core.profiler.profiler_analysis_pb2'})
_sym_db.RegisterMessage(ProfileSessionDataResponse)
_PROFILESESSIONDATAREQUEST_PARAMETERSENTRY._options = None
_PROFILEANALYSIS = _descriptor.ServiceDescriptor(name='ProfileAnalysis', full_name='tensorflow.ProfileAnalysis', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=894, serialized_end=1222, methods=[_descriptor.MethodDescriptor(name='NewSession', full_name='tensorflow.ProfileAnalysis.NewSession', index=0, containing_service=None, input_type=_NEWPROFILESESSIONREQUEST, output_type=_NEWPROFILESESSIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='EnumSessions', full_name='tensorflow.ProfileAnalysis.EnumSessions', index=1, containing_service=None, input_type=_ENUMPROFILESESSIONSANDTOOLSREQUEST, output_type=_ENUMPROFILESESSIONSANDTOOLSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetSessionToolData', full_name='tensorflow.ProfileAnalysis.GetSessionToolData', index=2, containing_service=None, input_type=_PROFILESESSIONDATAREQUEST, output_type=_PROFILESESSIONDATARESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_PROFILEANALYSIS)
DESCRIPTOR.services_by_name['ProfileAnalysis'] = _PROFILEANALYSIS



from . import table
from . import env
from . import core
from . import errors
from . import naming
from . import tensor
from . import tensor_shape
from . import file_system
from . import file_system_helper
from . import random
from . import port
from . import table_options
from . import table_builder
from .tensorflow.python.platform import tf_logging as logging
from .pb.tensorflow.core.protobuf import tensor_bundle_pb2
from .pb.tensorflow.core.framework import types_pb2

from typing import Tuple, Optional, List, Dict
import time
import sys
import dataclasses

# // Versioning of the tensor bundle format.
# const int kTensorBundleMinProducer = 0;
# const int kTensorBundleMinConsumer = 0;
# const int kTensorBundleVersion = 1;
kTensorBundleMinProducer = 0
kTensorBundleMinConsumer = 0
kTensorBundleVersion = 1

# // Size of our input buffer for streaming reads
# static const int kBufferSize = 1024 * 1024;
kBufferSize = 1024 * 1024

# // Key to the special BundleHeaderProto entry.  Do not change this, as clients
# // can make the assumption that the header is always the first entry in the
# // bundle.
# const char* const kHeaderEntryKey = "";
kHeaderEntryKey = b""

def _memcpy(dst: core.StringPiece, data: core.StringPiece, size: int):
  dst[:size] = data[:size]

def AlignedMalloc(size: int) -> core.StringPiece:
  return core.StringPiece(bytearray(size))

class FileOutputBuffer:
  """A buffering wrapper for a WritableFile.  Useful if the caller wishes to issue
  small writes to a file (e.g. writing out a list of small varints).
  External synchronization must be used in the presence of concurrent callers."""
  def __init__(self, file: file_system.WritableFile, buffer_size: int):
    assert buffer_size > 0
    self._file = file
    self._position = 0
    self._buffer_size = buffer_size
    # Checksum of all appended bytes since construction or last clear_crc32c().
    self._crc32c = 0
    self._buffer_ptr = AlignedMalloc(buffer_size)

  # // Buffered append.
  # Status Append(StringPiece data);
  def append(self, data: core.StringPiece) -> errors.Status:
    # In the below, it is critical to calculate the checksum on the actually
    # copied bytes, not the source bytes.  This is because "data" typically
    # points to tensor buffers, which may be concurrently written.
    if data.size() + self._position <= self._buffer_size:
      # Can fit into the current buffer.
      _memcpy(self._buffer_ptr + self._position, data.data(), data.size())
      self._crc32c = core.crc32c.extend(self._crc32c, data.data(), data.size())
    elif data.size() <= self._buffer_size:
      # Cannot fit, but can fit after flushing.
      errors.raise_if_error(self._flush_buffer(closing=False))
      _memcpy(self._buffer_ptr, data.data(), data.size())
      self._crc32c = core.crc32c.extend(self._crc32c, self._buffer_ptr, data.size())
    else:
      # Cannot fit even after flushing.  So we break down "data" by chunk, and
      # flush/checksum each chunk.
      errors.raise_if_error(self._flush_buffer(closing=False))
      for i in range(0, data.size(), self._buffer_size):
        nbytes = min(data.size() - i, self._buffer_size)
        _memcpy(self._buffer_ptr, data.data() + i, nbytes)
        self._crc32c = core.crc32c.extend(self._crc32c, self._buffer_ptr, nbytes)
        self._position = nbytes
        errors.raise_if_error(self._flush_buffer(closing=False))
      return errors.Status.OK()
    self._position += data.size()
    return errors.Status.OK()

  def crc32c(self):
    """Returns the running crc32c checksum of all currently appended bytes."""
    return self._crc32c

  def clear_crc32c(self):
    """Clears the running crc32c checksum."""
    self._crc32c = 0

  def close(self) -> errors.Status:
    """Appends the buffered data, then closes the underlying file."""
    status = self._flush_buffer(closing=False)
    if not status.ok():
      return status
    return self._file.close()

  def _flush_buffer(self, closing: bool) -> errors.Status:
    """Appends the buffered data to the underlying file. Does NOT flush the file."""
    if self._position > 0:
      # Use Cord to avoid extra data copy for some WritableFile implementations.
      # absl::Cord buffer = absl::MakeCordFromExternal(
      #     StringPiece(buffer_ptr_, position_),
      #     [ptr = buffer_ptr_](StringPiece) { port::AlignedFree(ptr); });
      buffer = core.StringPiece(self._buffer_ptr, self._position)
      self._buffer_ptr = None if closing else AlignedMalloc(self._buffer_size)
      errors.raise_if_error(self._file.append(buffer))
      self._position = 0
    return errors.Status.OK()


# // Serializes the data bytes of the non-string tensor "val".  Discards the
# // original content of "bytes_written", and on OK updates it with number of
# // bytes written.
# // REQUIRES: val.dtype() != DT_STRING
# Status WriteTensor(const Tensor& val, FileOutputBuffer* out,
#                    size_t* bytes_written) {
#   DCHECK_NE(val.dtype(), DT_STRING);
#   DCHECK_NE(val.dtype(), DT_VARIANT);
#   *bytes_written = val.TotalBytes();
#   char* buf = GetBackingBuffer(val);
#   VLOG(1) << "Appending " << *bytes_written << " bytes to file";
#   return out->Append(StringPiece(buf, *bytes_written));
# }
def WriteTensor(val: tensor.Tensor, out: FileOutputBuffer) -> Tuple[errors.Status, int]:
  """Serializes the data bytes of the non-string tensor "val".  Returns the number
  of bytes.

  REQUIRES: val.dtype() != DT_STRING"""
  assert val.dtype() != types_pb2.DT_STRING
  assert val.dtype() != types_pb2.DT_VARIANT
  bytes_written = val.total_bytes()
  buf = GetBackingBuffer(val)
  return out.append(core.StringPiece(buf, bytes_written)), bytes_written

# char* GetBackingBuffer(const Tensor& val) {
#   CHECK(DataTypeCanUseMemcpy(val.dtype())) << val.dtype();
#   return const_cast<char*>(val.tensor_data().data());
# }
def GetBackingBuffer(val: tensor.Tensor) -> core.StringPiece:
  return val.tensor_data().data()

# // Writes zeros to output buffer to align the next write to the requested
# // alignment. "size" is the current size of the buffer and is updated to the
# // new size.
# Status PadAlignment(FileOutputBuffer* out, int alignment, int64* size) {
#   int bytes_over = *size % alignment;
#   if (bytes_over == 0) {
#     return Status::OK();
#   }
#   int bytes_to_write = alignment - bytes_over;
#   Status status = out->Append(string(bytes_to_write, '\0'));
#   if (status.ok()) {
#     *size += bytes_to_write;
#   }
#   return status;
# }
def PadAlignment(out: FileOutputBuffer, alignment: int, size: int) -> Tuple[errors.Status, int]:
  bytes_over = size % alignment
  if bytes_over == 0:
    return errors.Status.OK(), size
  bytes_to_write = alignment - bytes_over
  status = out.append(core.string_view(bytearray(bytes_to_write)))
  if status.ok():
    size += bytes_to_write
    return status, size
  return status, size

class BundleWriter:
  """Builds a string-string table of tensor names to BundleEntryProto (metadata).

  On construction, attempts to create a directory given by the dirname of
  "prefix", so "status()" must be checked before calling any member functions.

  All threads accessing the same BundleWriter must synchronize.
  """
  @dataclasses.dataclass(frozen=True)
  class Options:
    data_alignment: int = 1
    """
    Alignment, in bytes, for tensor data.
    Must be >= 1. The default size of 1 densely packs tensors.
    """

  def __init__(self, env_: env.Env, prefix: core.StringPiece, options: Options = None):
    if options is None:
      options = self.Options()
    self._env = env_
    prefix = core.string_view(prefix)
    self._prefix = prefix.bytes()
    self._options = options
    self._out = None
    self._size = 0
    self._status = errors.Status.OK()
    self._entries: Dict[bytes, tensor_bundle_pb2.BundleEntryProto] = {}
    self._use_temp_file = errors.raise_if_error(env_.has_atomic_move(prefix.bytes()))

    # data_path_ = DataFilename(prefix_, 0, 1);
    # metadata_path_ = MetaFilename(prefix_);
    self._data_path = naming.data_filename(self._prefix, 0, 1)
    self._metadata_path = naming.meta_filename(self._prefix)
    # if (use_temp_file_) {
    #   data_path_ = strings::StrCat(data_path_, ".tempstate", random::New64());
    #   metadata_path_ =
    #       strings::StrCat(metadata_path_, ".tempstate", random::New64());
    # }
    if self._use_temp_file:
      self._data_path += f".tempstate{random.new_64()}".encode('utf-8')
      self._metadata_path += f".tempstate{random.new_64()}".encode('utf-8')

    # status_ = env_->CreateDir(string(io::Dirname(prefix_)));
    # if (!status_.ok() && !errors::IsAlreadyExists(status_)) {
    #   return;
    # }

    # std::unique_ptr<WritableFile> wrapper;
    # status_ = env_->NewWritableFile(data_path_, &wrapper);
    # if (!status_.ok()) return;
    wrapper = errors.raise_if_error(env_.new_writable_file(self._data_path))
    # out_ = std::unique_ptr<FileOutputBuffer>(
    #     new FileOutputBuffer(wrapper.release(), 8 << 20 /* 8MB write buffer */));
    self._out = FileOutputBuffer(wrapper, 8 << 20) # 8MB write buffer

    # VLOG(1) << "Writing to file " << data_path_;
    logging.info("Writing to file %s", self._data_path)

  # Status Add(StringPiece key, const Tensor& val);
  def add(self, key: core.StringPiece, val: tensor.Tensor):
    """Adds the tensor "val" under key "key".

    Across calls "key" must be unique but can be added in any order."""
    # if (!status_.ok()) return status_;
    if not self._status.ok():
      return self._status
    # CHECK_NE(key, kHeaderEntryKey);
    assert key != kHeaderEntryKey
    key = core.string_view(key)
    if not isinstance(val, tensor.Tensor):
      # try to convert to Tensor from a numpy array.
      val = tensor.Tensor.from_array(val)
    # const string key_string(key);
    key_string = key.bytes()
    # if (entries_.find(key_string) != entries_.end()) {
    #   status_ = errors::InvalidArgument("Adding duplicate key: ", key);
    #   return status_;
    # }
    if key_string in self._entries:
      self._status = errors.InvalidArgument("Adding duplicate key: ", key)
      return self._status
    # BundleEntryProto* entry = &entries_[key_string];
    entry = self._entries.setdefault(key_string, tensor_bundle_pb2.BundleEntryProto())
    entry: tensor_bundle_pb2.BundleEntryProto
    # entry->set_dtype(val.dtype());
    entry.dtype = val.dtype()
    # val.shape().AsProto(entry->mutable_shape());
    val.shape().as_proto(entry.shape)
    # entry->set_shard_id(0);
    # entry->set_offset(size_);
    entry.shard_id = 0
    entry.offset = self._size

    # // Updates the data file.
    # size_t data_bytes_written = 0;
    # uint32 crc32c = 0;
    # out_->clear_crc32c();
    self._out.clear_crc32c()
    # if (val.dtype() == DT_STRING) {
    #   status_ = WriteStringTensor(val, out_.get(), &data_bytes_written, &crc32c);
    # } else if (val.dtype() == DT_VARIANT) {
    #   status_ = WriteVariantTensor(val, out_.get(), &data_bytes_written, &crc32c);
    # } else {
    #   status_ = WriteTensor(val, out_.get(), &data_bytes_written);
    #   crc32c = out_->crc32c();
    # }
    if val.dtype() == types_pb2.DT_STRING:
      raise NotImplementedError("TODO: support string tensors")
      self._status, data_bytes_written, crc32c = WriteStringTensor(val, self._out)
    elif val.dtype() == types_pb2.DT_VARIANT:
      raise NotImplementedError("TODO: support variant tensors")
      self._status, data_bytes_written, crc32c = WriteVariantTensor(val, self._out)
    else:
      self._status, data_bytes_written = WriteTensor(val, self._out)
      crc32c = self._out.crc32c()

    # if (status_.ok()) {
    #   entry->set_size(data_bytes_written);
    #   entry->set_crc32c(crc32c::Mask(crc32c));
    #   size_ += data_bytes_written;
    #   status_ = PadAlignment(out_.get(), options_.data_alignment, &size_);
    # }
    if self._status.ok():
      entry.size = data_bytes_written
      entry.crc32c = core.crc32c.mask(crc32c)
      self._size += data_bytes_written
      self._status, self._size = PadAlignment(self._out, self._options.data_alignment, self._size)
    return self._status

  # // Partitioned variables support.
  # // A slice of a full tensor is stored in two entries in the metadata table:
  # //
  # //   full_tensor_key   -> BundleEntryProto, describing all stored slices
  # //                        of this full tensor.  Does not append to the data
  # //                        file.
  # //   encoded slice key -> BundleEntryProto, describing one particular slice.
  # //                        Appends values of this slice to the data file.
  # //
  # // Slices of a full tensor can be added in any order.
  # //
  # // If a full tensor has slices placed on N devices and N BundleWriter's are
  # // concurrently used, the caller must use MergeBundles() to ensure that a
  # // consistent entry for "full_tensor_key" is produced.
  # //
  # // Returns an error if the same slice is added the second time.
  # Status AddSlice(StringPiece full_tensor_key,
  #                 const TensorShape& full_tensor_shape,
  #                 const TensorSlice& slice_spec, const Tensor& slice_tensor);
  #
  # // Finishes the writer and flushes.
  # Status Finish() TF_MUST_USE_RESULT;
  def finish(self) -> errors.Status:
    """Finishes the writer and flushes."""
    # if (out_) {
    #   status_.Update(out_->Close());
    #   out_ = nullptr;
    #   if (status_.ok()) {
    #     if (use_temp_file_) {
    #       status_ =
    #           Env::Default()->RenameFile(data_path_, DataFilename(prefix_, 0, 1));
    #     }
    #   } else {
    #     Env::Default()->DeleteFile(data_path_).IgnoreError();
    #   }
    # }
    if self._out is not None:
      self._status.update(self._out.close())
      self._out = None
      if self._status.ok():
        if self._use_temp_file:
          self._status = self._env.rename_file(self._data_path, naming.data_filename(self._prefix, 0, 1))
        else:
          self._env.delete_file(self._data_path) # ignore error
    # if (!status_.ok()) return status_;
    if not self._status.ok():
      return self._status
    # // Build key -> BundleEntryProto table.
    # std::unique_ptr<WritableFile> file;
    # status_ = env_->NewWritableFile(metadata_path_, &file);
    self._status, file = self._env.new_writable_file(self._metadata_path)
    # if (!status_.ok()) return status_;
    if not self._status.ok():
      return self._status
    # {
    if True:
      # // N.B.: the default use of Snappy compression may not be supported on all
      # // platforms (e.g. Android).  The metadata file is small, so this is fine.
      # table::Options options;
      # options.compression = table::kNoCompression;
      options = table_options.Options(compression=table_options.kNoCompression)
      # table::TableBuilder builder(options, file.get());
      builder = table_builder.TableBuilder(options, file)
      # // Header entry.
      # BundleHeaderProto header;
      header = tensor_bundle_pb2.BundleHeaderProto()
      # header.set_num_shards(1);
      header.num_shards = 1
      # header.set_endianness(BundleHeaderProto::LITTLE);
      header.endianness = tensor_bundle_pb2.BundleHeaderProto.LITTLE
      # if (!port::kLittleEndian) header.set_endianness(BundleHeaderProto::BIG);
      if not port.kLittleEndian:
        header.endianness = tensor_bundle_pb2.BundleHeaderProto.BIG
      # VersionDef* version = header.mutable_version();
      # version->set_producer(kTensorBundleVersion);
      header.version.producer = kTensorBundleVersion
      # version->set_min_consumer(kTensorBundleMinConsumer);
      header.version.min_consumer = kTensorBundleMinConsumer
      #
      # builder.Add(kHeaderEntryKey, header.SerializeAsString());
      builder.add(kHeaderEntryKey, header.SerializeToString())
      #
      # // All others.
      # for (const auto& p : entries_) {
      #   builder.Add(p.first, p.second.SerializeAsString());
      # }
      for name, value in self._entries.items():
        builder.add(name, value.SerializeToString())
      # status_ = builder.Finish();
      self._status = builder.finish()
    # }
    # status_.Update(file->Close());
    self._status.update(file.close())
    # if (!status_.ok()) {
    #   Env::Default()->DeleteFile(metadata_path_).IgnoreError();
    #   return status_;
    if not self._status.ok():
      self._env.delete_file(self._metadata_path) # ignore error
      return self._status
    # } else if (use_temp_file_) {
    #   status_ = Env::Default()->RenameFile(metadata_path_, MetaFilename(prefix_));
    #   if (!status_.ok()) return status_;
    # }
    elif self._use_temp_file:
      self._status = self._env.rename_file(self._metadata_path, naming.meta_filename(self._prefix))
      if not self._status.ok():
        return self._status
    # status_ = errors::Internal("BundleWriter is closed");
    self._status = errors.Internal("BundleWriter is closed")
    # return Status::OK();
    return errors.Status.OK()

  # Status status() const { return status_; }
  def status(self):
    return self._status




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from ....tensorflow.core.framework import tensor_pb2 as tensorflow_dot_core_dot_framework_dot_tensor__pb2
from ....tensorflow.core.profiler import tfprof_log_pb2 as tensorflow_dot_core_dot_profiler_dot_tfprof__log__pb2
from ....tensorflow.core.protobuf import debug_pb2 as tensorflow_dot_core_dot_protobuf_dot_debug__pb2
from ....tensorflow.core.util import event_pb2 as tensorflow_dot_core_dot_util_dot_event__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/core/debug/debug_service.proto', package='tensorflow', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n)tensorflow/core/debug/debug_service.proto\x12\ntensorflow\x1a&tensorflow/core/framework/tensor.proto\x1a)tensorflow/core/profiler/tfprof_log.proto\x1a$tensorflow/core/protobuf/debug.proto\x1a tensorflow/core/util/event.proto"\xde\x02\n\nEventReply\x12I\n\x16debug_op_state_changes\x18\x01 \x03(\x0b2).tensorflow.EventReply.DebugOpStateChange\x12\'\n\x06tensor\x18\x02 \x01(\x0b2\x17.tensorflow.TensorProto\x1a\xdb\x01\n\x12DebugOpStateChange\x12>\n\x05state\x18\x01 \x01(\x0e2/.tensorflow.EventReply.DebugOpStateChange.State\x12\x11\n\tnode_name\x18\x02 \x01(\t\x12\x13\n\x0boutput_slot\x18\x03 \x01(\x05\x12\x10\n\x08debug_op\x18\x04 \x01(\t"K\n\x05State\x12\x15\n\x11STATE_UNSPECIFIED\x10\x00\x12\x0c\n\x08DISABLED\x10\x01\x12\r\n\tREAD_ONLY\x10\x02\x12\x0e\n\nREAD_WRITE\x10\x03"\xa7\x03\n\rCallTraceback\x125\n\tcall_type\x18\x01 \x01(\x0e2".tensorflow.CallTraceback.CallType\x12\x10\n\x08call_key\x18\x02 \x01(\t\x120\n\x0corigin_stack\x18\x03 \x01(\x0b2\x1a.tensorflow.tfprof.CodeDef\x12L\n\x13origin_id_to_string\x18\x04 \x03(\x0b2/.tensorflow.CallTraceback.OriginIdToStringEntry\x126\n\x0fgraph_traceback\x18\x05 \x01(\x0b2\x1d.tensorflow.tfprof.OpLogProto\x12\x15\n\rgraph_version\x18\x06 \x01(\x03\x1a7\n\x15OriginIdToStringEntry\x12\x0b\n\x03key\x18\x01 \x01(\x03\x12\r\n\x05value\x18\x02 \x01(\t:\x028\x01"E\n\x08CallType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x13\n\x0fGRAPH_EXECUTION\x10\x01\x12\x13\n\x0fEAGER_EXECUTION\x10\x022\xdd\x01\n\rEventListener\x12;\n\nSendEvents\x12\x11.tensorflow.Event\x1a\x16.tensorflow.EventReply(\x010\x01\x12C\n\x0eSendTracebacks\x12\x19.tensorflow.CallTraceback\x1a\x16.tensorflow.EventReply\x12J\n\x0fSendSourceFiles\x12\x1f.tensorflow.DebuggedSourceFiles\x1a\x16.tensorflow.EventReplyb\x06proto3', dependencies=[tensorflow_dot_core_dot_framework_dot_tensor__pb2.DESCRIPTOR, tensorflow_dot_core_dot_profiler_dot_tfprof__log__pb2.DESCRIPTOR, tensorflow_dot_core_dot_protobuf_dot_debug__pb2.DESCRIPTOR, tensorflow_dot_core_dot_util_dot_event__pb2.DESCRIPTOR])
_EVENTREPLY_DEBUGOPSTATECHANGE_STATE = _descriptor.EnumDescriptor(name='State', full_name='tensorflow.EventReply.DebugOpStateChange.State', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='STATE_UNSPECIFIED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='DISABLED', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='READ_ONLY', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='READ_WRITE', index=3, number=3, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=488, serialized_end=563)
_sym_db.RegisterEnumDescriptor(_EVENTREPLY_DEBUGOPSTATECHANGE_STATE)
_CALLTRACEBACK_CALLTYPE = _descriptor.EnumDescriptor(name='CallType', full_name='tensorflow.CallTraceback.CallType', filename=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key, values=[_descriptor.EnumValueDescriptor(name='UNSPECIFIED', index=0, number=0, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='GRAPH_EXECUTION', index=1, number=1, serialized_options=None, type=None, create_key=_descriptor._internal_create_key), _descriptor.EnumValueDescriptor(name='EAGER_EXECUTION', index=2, number=2, serialized_options=None, type=None, create_key=_descriptor._internal_create_key)], containing_type=None, serialized_options=None, serialized_start=920, serialized_end=989)
_sym_db.RegisterEnumDescriptor(_CALLTRACEBACK_CALLTYPE)
_EVENTREPLY_DEBUGOPSTATECHANGE = _descriptor.Descriptor(name='DebugOpStateChange', full_name='tensorflow.EventReply.DebugOpStateChange', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='state', full_name='tensorflow.EventReply.DebugOpStateChange.state', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='node_name', full_name='tensorflow.EventReply.DebugOpStateChange.node_name', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='output_slot', full_name='tensorflow.EventReply.DebugOpStateChange.output_slot', index=2, number=3, type=5, cpp_type=1, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='debug_op', full_name='tensorflow.EventReply.DebugOpStateChange.debug_op', index=3, number=4, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[_EVENTREPLY_DEBUGOPSTATECHANGE_STATE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=344, serialized_end=563)
_EVENTREPLY = _descriptor.Descriptor(name='EventReply', full_name='tensorflow.EventReply', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='debug_op_state_changes', full_name='tensorflow.EventReply.debug_op_state_changes', index=0, number=1, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='tensor', full_name='tensorflow.EventReply.tensor', index=1, number=2, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_EVENTREPLY_DEBUGOPSTATECHANGE], enum_types=[], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=213, serialized_end=563)
_CALLTRACEBACK_ORIGINIDTOSTRINGENTRY = _descriptor.Descriptor(name='OriginIdToStringEntry', full_name='tensorflow.CallTraceback.OriginIdToStringEntry', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='key', full_name='tensorflow.CallTraceback.OriginIdToStringEntry.key', index=0, number=1, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='value', full_name='tensorflow.CallTraceback.OriginIdToStringEntry.value', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[], enum_types=[], serialized_options=b'8\x01', is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=863, serialized_end=918)
_CALLTRACEBACK = _descriptor.Descriptor(name='CallTraceback', full_name='tensorflow.CallTraceback', filename=None, file=DESCRIPTOR, containing_type=None, create_key=_descriptor._internal_create_key, fields=[_descriptor.FieldDescriptor(name='call_type', full_name='tensorflow.CallTraceback.call_type', index=0, number=1, type=14, cpp_type=8, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='call_key', full_name='tensorflow.CallTraceback.call_key', index=1, number=2, type=9, cpp_type=9, label=1, has_default_value=False, default_value=b''.decode('utf-8'), message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='origin_stack', full_name='tensorflow.CallTraceback.origin_stack', index=2, number=3, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='origin_id_to_string', full_name='tensorflow.CallTraceback.origin_id_to_string', index=3, number=4, type=11, cpp_type=10, label=3, has_default_value=False, default_value=[], message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_traceback', full_name='tensorflow.CallTraceback.graph_traceback', index=4, number=5, type=11, cpp_type=10, label=1, has_default_value=False, default_value=None, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key), _descriptor.FieldDescriptor(name='graph_version', full_name='tensorflow.CallTraceback.graph_version', index=5, number=6, type=3, cpp_type=2, label=1, has_default_value=False, default_value=0, message_type=None, enum_type=None, containing_type=None, is_extension=False, extension_scope=None, serialized_options=None, file=DESCRIPTOR, create_key=_descriptor._internal_create_key)], extensions=[], nested_types=[_CALLTRACEBACK_ORIGINIDTOSTRINGENTRY], enum_types=[_CALLTRACEBACK_CALLTYPE], serialized_options=None, is_extendable=False, syntax='proto3', extension_ranges=[], oneofs=[], serialized_start=566, serialized_end=989)
_EVENTREPLY_DEBUGOPSTATECHANGE.fields_by_name['state'].enum_type = _EVENTREPLY_DEBUGOPSTATECHANGE_STATE
_EVENTREPLY_DEBUGOPSTATECHANGE.containing_type = _EVENTREPLY
_EVENTREPLY_DEBUGOPSTATECHANGE_STATE.containing_type = _EVENTREPLY_DEBUGOPSTATECHANGE
_EVENTREPLY.fields_by_name['debug_op_state_changes'].message_type = _EVENTREPLY_DEBUGOPSTATECHANGE
_EVENTREPLY.fields_by_name['tensor'].message_type = tensorflow_dot_core_dot_framework_dot_tensor__pb2._TENSORPROTO
_CALLTRACEBACK_ORIGINIDTOSTRINGENTRY.containing_type = _CALLTRACEBACK
_CALLTRACEBACK.fields_by_name['call_type'].enum_type = _CALLTRACEBACK_CALLTYPE
_CALLTRACEBACK.fields_by_name['origin_stack'].message_type = tensorflow_dot_core_dot_profiler_dot_tfprof__log__pb2._CODEDEF
_CALLTRACEBACK.fields_by_name['origin_id_to_string'].message_type = _CALLTRACEBACK_ORIGINIDTOSTRINGENTRY
_CALLTRACEBACK.fields_by_name['graph_traceback'].message_type = tensorflow_dot_core_dot_profiler_dot_tfprof__log__pb2._OPLOGPROTO
_CALLTRACEBACK_CALLTYPE.containing_type = _CALLTRACEBACK
DESCRIPTOR.message_types_by_name['EventReply'] = _EVENTREPLY
DESCRIPTOR.message_types_by_name['CallTraceback'] = _CALLTRACEBACK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
EventReply = _reflection.GeneratedProtocolMessageType('EventReply', (_message.Message,), {'DebugOpStateChange': _reflection.GeneratedProtocolMessageType('DebugOpStateChange', (_message.Message,), {'DESCRIPTOR': _EVENTREPLY_DEBUGOPSTATECHANGE, '__module__': 'tensorflow.core.debug.debug_service_pb2'}), 'DESCRIPTOR': _EVENTREPLY, '__module__': 'tensorflow.core.debug.debug_service_pb2'})
_sym_db.RegisterMessage(EventReply)
_sym_db.RegisterMessage(EventReply.DebugOpStateChange)
CallTraceback = _reflection.GeneratedProtocolMessageType('CallTraceback', (_message.Message,), {'OriginIdToStringEntry': _reflection.GeneratedProtocolMessageType('OriginIdToStringEntry', (_message.Message,), {'DESCRIPTOR': _CALLTRACEBACK_ORIGINIDTOSTRINGENTRY, '__module__': 'tensorflow.core.debug.debug_service_pb2'}), 'DESCRIPTOR': _CALLTRACEBACK, '__module__': 'tensorflow.core.debug.debug_service_pb2'})
_sym_db.RegisterMessage(CallTraceback)
_sym_db.RegisterMessage(CallTraceback.OriginIdToStringEntry)
_CALLTRACEBACK_ORIGINIDTOSTRINGENTRY._options = None
_EVENTLISTENER = _descriptor.ServiceDescriptor(name='EventListener', full_name='tensorflow.EventListener', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=992, serialized_end=1213, methods=[_descriptor.MethodDescriptor(name='SendEvents', full_name='tensorflow.EventListener.SendEvents', index=0, containing_service=None, input_type=tensorflow_dot_core_dot_util_dot_event__pb2._EVENT, output_type=_EVENTREPLY, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='SendTracebacks', full_name='tensorflow.EventListener.SendTracebacks', index=1, containing_service=None, input_type=_CALLTRACEBACK, output_type=_EVENTREPLY, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='SendSourceFiles', full_name='tensorflow.EventListener.SendSourceFiles', index=2, containing_service=None, input_type=tensorflow_dot_core_dot_protobuf_dot_debug__pb2._DEBUGGEDSOURCEFILES, output_type=_EVENTREPLY, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_EVENTLISTENER)
DESCRIPTOR.services_by_name['EventListener'] = _EVENTLISTENER



from typing import Callable, Optional, List, Tuple
from fnmatch import fnmatch
from abc import ABC, abstractmethod
import os

from . import errors
from . import core
from . import io
from . import file_statistics


class RandomAccessFile(ABC):
  """A file abstraction for randomly reading the contents of a file."""

  def name(self) -> Tuple[errors.Status, core.StringPiece]:
    """Returns the name of the file.

    This is an optional operation that may not be implemented by every
    filesystem."""
    return errors.Unimplemented("This filesystem does not support name()"), core.StringPiece()

  @abstractmethod
  def close(self) -> errors.Status:
    return errors.Unimplemented("This filesystem does not support close()")

  @abstractmethod
  def read(self, offset: int, n: int) -> Tuple[errors.Status, core.StringPiece]:
    """Reads up to `n` bytes from the file starting at `offset`.

    Returns `OUT_OF_RANGE` if fewer than n bytes were stored in `*result`
    because of EOF.

    Safe for concurrent use by multiple threads."""
    return errors.Unimplemented("This filesystem does not support read()"), core.StringPiece()

  def __enter__(self):
    return self

  def __exit__(self, *args):
    errors.raise_if_error(self.close())

  def __del__(self):
    errors.raise_if_error(self.close())

class WritableFile(ABC):
  """A file abstraction for sequential writing.

  The implementation must provide buffering since callers may append
  small fragments at a time to the file."""

  def name(self) -> Tuple[errors.Status, core.StringPiece]:
    """Returns the name of the file.

    This is an optional operation that may not be implemented by every
    filesystem."""
    return errors.Unimplemented("This filesystem does not support name()"), core.StringPiece()

  @abstractmethod
  def close(self) -> errors.Status:
    """Close the file.

    Flush() and de-allocate resources associated with this file

    Typical return codes (not guaranteed to be exhaustive):
     * OK
     * Other codes, as returned from Flush()
    """
    return errors.Unimplemented("This filesystem does not support close()")

  @abstractmethod
  def append(self, data: core.StringPiece) -> errors.Status:
    """Append 'data' to the file."""
    return errors.Unimplemented("This filesystem does not support append()")

  @abstractmethod
  def flush(self) -> errors.Status:
    """Flushes the file and optionally syncs contents to filesystem.

    This should flush any local buffers whose contents have not been
    delivered to the filesystem.

    If the process terminates after a successful flush, the contents
    may still be persisted, since the underlying filesystem may
    eventually flush the contents.  If the OS or machine crashes
    after a successful flush, the contents may or may not be
    persisted, depending on the implementation.
    """
    return errors.Unimplemented("This filesystem does not support flush()")

  @abstractmethod
  def sync(self) -> errors.Status:
    """Syncs contents of file to filesystem.

    This waits for confirmation from the filesystem that the contents
    of the file have been persisted to the filesystem; if the OS
    or machine crashes after a successful Sync, the contents should
    be properly saved."""
    return errors.Unimplemented("This filesystem does not support sync()")

  @abstractmethod
  def tell(self) -> Tuple[errors.Status, int]:
    """Retrieves the current write position in the file, or -1 on error.

    This is an optional operation, subclasses may choose to return
    errors::Unimplemented.
    """
    return errors.Unimplemented("This filesystem does not support tell()"), -1

  def __enter__(self):
    return self

  def __exit__(self, *args):
    errors.raise_if_error(self.close())

  def __del__(self):
    errors.raise_if_error(self.close())

class FileSystem(ABC):
  def parse_uri(self, name) -> Tuple[core.StringPiece, core.StringPiece, core.StringPiece]:
    return io.parse_uri(name)

  def match(self, filename, pattern):
    filename = core.string_view(filename)
    pattern = core.string_view(pattern)
    return fnmatch(filename.bytes(), pattern.bytes())

  def translate_name(self, name) -> bytes:
    name = core.string_view(name)
    # If the name is empty, CleanPath returns "." which is incorrect and
    # we should return the empty path instead.
    if name.empty():
      return name.bytes()
    # Otherwise, properly separate the URI components and clean the path one
    scheme, host, path = self.parse_uri(name)
    # If `path` becomes empty, return `/` (`file://` should be `/`), not `.`.
    if path.empty():
      return b"/"

    return self.clean_path(path)

  def clean_path(self, name) -> bytes:
    name = core.string_view(name)
    result = os.path.normpath(name.bytes())
    return result

  @abstractmethod
  def new_random_access_file(self, name) -> Tuple[errors.Status, Optional[RandomAccessFile]]:
    return errors.Unimplemented("This filesystem does not support new_random_access_file()"), None

  @abstractmethod
  def new_writable_file(self, name) -> Tuple[errors.Status, Optional[WritableFile]]:
    return errors.Unimplemented("This filesystem does not support new_writable_file()"), None

  def has_atomic_move(self, name) -> Tuple[errors.Status, bool]:
    return errors.Status.OK(), True

  @abstractmethod
  def rename_file(self, src, target) -> errors.Status:
    return errors.Status.OK()

  @abstractmethod
  def get_file_size(self, name) -> Tuple[errors.Status, int]:
    return errors.Status.OK(), 0

  @abstractmethod
  def delete_file(self, name) -> errors.Status:
    return errors.Status.OK()

  @abstractmethod
  def file_exists(self, name) -> errors.Status:
    return errors.Status.OK()

  @abstractmethod
  def get_matching_paths(self, pattern) -> Tuple[errors.Status, Optional[List]]:
    """Given a pattern, stores in *results the set of paths that matches
    that pattern. *results is cleared.

    pattern must match all of a name, not just a substring.

    pattern: { term }
    term:
      '*': matches any sequence of non-'/' characters
      '?': matches a single non-'/' character
      '[' [ '^' ] { match-list } ']':
           matches any single character (not) on the list
      c: matches character c (c != '*', '?', '\\', '[')
      '\\' c: matches character c
    character-range:
      c: matches character c (c != '\\', '-', ']')
      '\\' c: matches character c
      lo '-' hi: matches character c for lo <= c <= hi

    Typical return codes:
     * OK - no errors
     * UNIMPLEMENTED - Some underlying functions (like GetChildren) are not
                       implemented
    """
    return errors.Status.OK(), []

  @abstractmethod
  def stat(self, name, stats: file_statistics.FileStatistics) -> errors.Status:
    return errors.Status.OK()

  @abstractmethod
  def get_children(self, dir) -> Tuple[errors.Status, List[bytes]]:
    return errors.Status.OK(), []

  def is_directory(self, name) -> errors.Status:
    err = self.file_exists(name)
    if not err.ok():
      return err
    stat = file_statistics.FileStatistics()
    err = self.stat(name, stat)
    if not err.ok():
      return err
    if stat.is_directory:
      return errors.Status.OK()
    return errors.FailedPrecondition("Not a directory")


class FileSystemRegistry(ABC):
  Factory = Callable[[], FileSystem]

  @abstractmethod
  def register_factory(self, scheme: str, factory: Factory) -> errors.Status:
    raise NotImplementedError()

  @abstractmethod
  def register_filesystem(self, scheme: str, filesystem: FileSystem) -> errors.Status:
    raise NotImplementedError()

  @abstractmethod
  def lookup(self, scheme: str) -> Optional[FileSystem]:
    raise NotImplementedError()

  @abstractmethod
  def get_registered_file_system_schemes(self, schemes: List[str]) -> errors.Status:
    raise NotImplementedError()




'Generated protocol buffer code.'
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
_sym_db = _symbol_database.Default()
from .....tensorflow.compiler.xla import xla_pb2 as tensorflow_dot_compiler_dot_xla_dot_xla__pb2
DESCRIPTOR = _descriptor.FileDescriptor(name='tensorflow/compiler/xla/rpc/xla_service.proto', package='xla', syntax='proto3', serialized_options=None, create_key=_descriptor._internal_create_key, serialized_pb=b'\n-tensorflow/compiler/xla/rpc/xla_service.proto\x12\x03xla\x1a!tensorflow/compiler/xla/xla.proto2\xea\n\n\nXlaService\x12?\n\nUnregister\x12\x16.xla.UnregisterRequest\x1a\x17.xla.UnregisterResponse"\x00\x12Q\n\x10DeconstructTuple\x12\x1c.xla.DeconstructTupleRequest\x1a\x1d.xla.DeconstructTupleResponse"\x00\x123\n\x06Unpack\x12\x12.xla.UnpackRequest\x1a\x13.xla.UnpackResponse"\x00\x129\n\x08GetShape\x12\x14.xla.GetShapeRequest\x1a\x15.xla.GetShapeResponse"\x00\x12^\n\x18GetComputationGraphStats\x12!.xla.ComputationGraphStatsRequest\x1a\x1d.xla.ComputationStatsResponse"\x00\x129\n\x08LoadData\x12\x14.xla.LoadDataRequest\x1a\x15.xla.LoadDataResponse"\x00\x12Q\n\x10TransferToClient\x12\x1c.xla.TransferToClientRequest\x1a\x1d.xla.TransferToClientResponse"\x00\x12Q\n\x10TransferToServer\x12\x1c.xla.TransferToServerRequest\x1a\x1d.xla.TransferToServerResponse"\x00\x12Q\n\x10TransferToInfeed\x12\x1c.xla.TransferToInfeedRequest\x1a\x1d.xla.TransferToInfeedResponse"\x00\x12Z\n\x13TransferFromOutfeed\x12\x1f.xla.TransferFromOutfeedRequest\x1a .xla.TransferFromOutfeedResponse"\x00\x12B\n\x0bResetDevice\x12\x17.xla.ResetDeviceRequest\x1a\x18.xla.ResetDeviceResponse"\x00\x12X\n\x14ComputeConstantGraph\x12 .xla.ComputeConstantGraphRequest\x1a\x1c.xla.ComputeConstantResponse"\x00\x12Q\n\x10GetDeviceHandles\x12\x1c.xla.GetDeviceHandlesRequest\x1a\x1d.xla.GetDeviceHandlesResponse"\x00\x12Z\n\x13CreateChannelHandle\x12\x1f.xla.CreateChannelHandleRequest\x1a .xla.CreateChannelHandleResponse"\x00\x126\n\x07Compile\x12\x13.xla.CompileRequest\x1a\x14.xla.CompileResponse"\x00\x126\n\x07Execute\x12\x13.xla.ExecuteRequest\x1a\x14.xla.ExecuteResponse"\x00\x12X\n\x14ExecuteGraphParallel\x12 .xla.ExecuteGraphParallelRequest\x1a\x1c.xla.ExecuteParallelResponse"\x00\x12Q\n\x10WaitForExecution\x12\x1c.xla.WaitForExecutionRequest\x1a\x1d.xla.WaitForExecutionResponse"\x00b\x06proto3', dependencies=[tensorflow_dot_compiler_dot_xla_dot_xla__pb2.DESCRIPTOR])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)
_XLASERVICE = _descriptor.ServiceDescriptor(name='XlaService', full_name='xla.XlaService', file=DESCRIPTOR, index=0, serialized_options=None, create_key=_descriptor._internal_create_key, serialized_start=90, serialized_end=1476, methods=[_descriptor.MethodDescriptor(name='Unregister', full_name='xla.XlaService.Unregister', index=0, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._UNREGISTERREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._UNREGISTERRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='DeconstructTuple', full_name='xla.XlaService.DeconstructTuple', index=1, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._DECONSTRUCTTUPLEREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._DECONSTRUCTTUPLERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Unpack', full_name='xla.XlaService.Unpack', index=2, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._UNPACKREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._UNPACKRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetShape', full_name='xla.XlaService.GetShape', index=3, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._GETSHAPEREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._GETSHAPERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetComputationGraphStats', full_name='xla.XlaService.GetComputationGraphStats', index=4, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._COMPUTATIONGRAPHSTATSREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._COMPUTATIONSTATSRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='LoadData', full_name='xla.XlaService.LoadData', index=5, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._LOADDATAREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._LOADDATARESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='TransferToClient', full_name='xla.XlaService.TransferToClient', index=6, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERTOCLIENTREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERTOCLIENTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='TransferToServer', full_name='xla.XlaService.TransferToServer', index=7, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERTOSERVERREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERTOSERVERRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='TransferToInfeed', full_name='xla.XlaService.TransferToInfeed', index=8, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERTOINFEEDREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERTOINFEEDRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='TransferFromOutfeed', full_name='xla.XlaService.TransferFromOutfeed', index=9, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERFROMOUTFEEDREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._TRANSFERFROMOUTFEEDRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ResetDevice', full_name='xla.XlaService.ResetDevice', index=10, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._RESETDEVICEREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._RESETDEVICERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ComputeConstantGraph', full_name='xla.XlaService.ComputeConstantGraph', index=11, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._COMPUTECONSTANTGRAPHREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._COMPUTECONSTANTRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='GetDeviceHandles', full_name='xla.XlaService.GetDeviceHandles', index=12, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._GETDEVICEHANDLESREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._GETDEVICEHANDLESRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='CreateChannelHandle', full_name='xla.XlaService.CreateChannelHandle', index=13, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._CREATECHANNELHANDLEREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._CREATECHANNELHANDLERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Compile', full_name='xla.XlaService.Compile', index=14, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._COMPILEREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._COMPILERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='Execute', full_name='xla.XlaService.Execute', index=15, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._EXECUTEREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._EXECUTERESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='ExecuteGraphParallel', full_name='xla.XlaService.ExecuteGraphParallel', index=16, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._EXECUTEGRAPHPARALLELREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._EXECUTEPARALLELRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key), _descriptor.MethodDescriptor(name='WaitForExecution', full_name='xla.XlaService.WaitForExecution', index=17, containing_service=None, input_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._WAITFOREXECUTIONREQUEST, output_type=tensorflow_dot_compiler_dot_xla_dot_xla__pb2._WAITFOREXECUTIONRESPONSE, serialized_options=None, create_key=_descriptor._internal_create_key)])
_sym_db.RegisterServiceDescriptor(_XLASERVICE)
DESCRIPTOR.services_by_name['XlaService'] = _XLASERVICE
